.model-display-data-container {
  color: var(--white-one);
  display: flex;
  font-size: 20px;
  font-weight: 400;
  justify-content: center;
  margin-top: 20px;
  position: absolute;
  width: 100%;
  z-index: 10;
}