import React from 'react';
import {
  PlusOutlined,
  MinusOutlined,
  HomeOutlined,
  InfoCircleFilled,
  CaretRightOutlined,
  PauseOutlined,
  CaretRightFilled,
  CaretDownFilled,
} from '@ant-design/icons';
import {
  ScaleBarIconTag,
  FrameBackIconTag,
  FrameForwardIconTag,
  HighlightStarTag,
  IndeterminateHighlightStarTag,
  NoHighlightStarTag,
} from '../assets/svgs';

export const Reset = <HomeOutlined />;
export const ZoomIn = <PlusOutlined />;
export const ZoomOut = <MinusOutlined />;
export const Info = <InfoCircleFilled />;
export const CaretRight = <CaretRightFilled />;
export const CaretDown = <CaretDownFilled />;
export const Pause = <PauseOutlined />;
export const Play = <CaretRightOutlined />;
export const ScaleBarIcon = ScaleBarIconTag;
export const FrameBack = FrameBackIconTag;
export const FrameForward = FrameForwardIconTag;
export const IndeterminateHighlightStar = IndeterminateHighlightStarTag;
export const HighlightStar = HighlightStarTag;
export const NoHighlightStar = NoHighlightStarTag;
