:root {
  --black-one: #000000;
  --white-one: #d8d8d8;
  --dark-one: #25222e;
  --dark-two: #141219;
  --dark-three: #1e1b26;
  --dark-four: #3d384b;
  --gray-one: #4a4658;
  --gray-two: #d3d3d3;
  --gray-three: #a0a0a0;
  --gray-four: #6e6e6e;
  --gray-five: #979797;
  --purple-one: #b59ff6;
  --light-purple: #d0c7ed;
}
