(()=>{"use strict";var t={1417:()=>{var t=["vis-type","instanceId","type","x","y","z","xrot","yrot","zrot","cr","nSubPoints"];function r(t){return r="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},r(t)}function e(t){var e=function(t,e){if("object"!=r(t)||!t)return t;var n=t[Symbol.toPrimitive];if(void 0!==n){var o=n.call(t,"string");if("object"!=r(o))return o;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(t)}(t);return"symbol"==r(e)?e:e+""}function n(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}function o(t){return o=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},o(t)}function a(t,r){return a=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(t,r){return t.__proto__=r,t},a(t,r)}function i(){try{var t=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){})))}catch(t){}return(i=function(){return!!t})()}function u(t){var r="function"==typeof Map?new Map:void 0;return u=function(t){if(null===t||!function(t){try{return-1!==Function.toString.call(t).indexOf("[native code]")}catch(r){return"function"==typeof t}}(t))return t;if("function"!=typeof t)throw new TypeError("Super expression must either be null or a function");if(void 0!==r){if(r.has(t))return r.get(t);r.set(t,e)}function e(){return function(t,r,e){if(i())return Reflect.construct.apply(null,arguments);var n=[null];n.push.apply(n,r);var o=new(t.bind.apply(t,n));return e&&a(o,e.prototype),o}(t,arguments,o(this).constructor)}return e.prototype=Object.create(t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),a(e,t)},u(t)}function c(t,r,n){return(r=e(r))in t?Object.defineProperty(t,r,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[r]=n,t}function f(t,e,a){return e=o(e),function(t,e){if(e&&("object"===r(e)||"function"==typeof e))return e;if(void 0!==e)throw new TypeError("Derived constructors may only return object or undefined");return n(t)}(t,p()?Reflect.construct(e,a||[],o(t).constructor):e.apply(t,a))}function p(){try{var t=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],(function(){})))}catch(t){}return(p=function(){return!!t})()}var l=function(t){return t.ERROR="error",t.INFO="info",t.WARNING="warning",t}({}),s=function(t){function r(t){var e,o=arguments.length>1&&void 0!==arguments[1]?arguments[1]:l.ERROR,a=arguments.length>2&&void 0!==arguments[2]?arguments[2]:"";!function(t,r){if(!(t instanceof r))throw new TypeError("Cannot call a class as a function")}(this,r);for(var i=arguments.length,u=new Array(i>3?i-3:0),p=3;p<i;p++)u[p-3]=arguments[p];return c(n(e=f(this,r,[].concat(u))),"htmlData",void 0),c(n(e),"level",void 0),e.name="FrontEndError",e.message=t,e.htmlData=a,e.level=o,e}return function(t,r){if("function"!=typeof r&&null!==r)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(r&&r.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),Object.defineProperty(t,"prototype",{writable:!1}),r&&a(t,r)}(r,t),e=r,Object.defineProperty(e,"prototype",{writable:!1}),e;var e}(u(Error));self.addEventListener("message",(function(r){var e=function(r){var e=[],n=[];return r.bundleData.forEach((function(r){for(var o=r.data,a=[],i=t.findIndex((function(t){return"nSubPoints"===t})),u=function(){var r=o[i],e=t.length+r;if(o.length<e){var n=t.map((function(t,r){return"".concat(t,": ").concat(o[r],"<br />")}));throw new s("Your data is malformed, there are too few entries.",l.ERROR,"Example attempt to parse your data: <pre>".concat(n.join(""),"</pre>"))}var u=o.splice(0,e);if(u.length<t.length){var c=t.map((function(t,r){return"".concat(t,": ").concat(u[r],"<br />")}));throw new s("Your data is malformed, there are less entries than expected for this agent. ",l.ERROR,"Example attempt to parse your data: <pre>".concat(c.join(""),"</pre>"))}var f,p=(f=u).reduce((function(r,e,n){return t[n]?r[t[n]]=e:n<f.length+r.nSubPoints&&r.subpoints.push(e),r}),{subpoints:[]});a.push(p)};o.length;)u();var c={time:r.time,frameNumber:r.frameNumber};e.push(a),n.push(c)})),{parsedAgentDataArray:e,frameDataArray:n}}(r.data),n=e.frameDataArray,o=e.parsedAgentDataArray;postMessage({frameDataArray:n,parsedAgentDataArray:o})}),!1)}},r={};function e(n){var o=r[n];if(void 0!==o)return o.exports;var a=r[n]={exports:{}};return t[n](a,a.exports,e),a.exports}e.m=t,e.c=r,e.o=(t,r)=>Object.prototype.hasOwnProperty.call(t,r),(()=>{e.S={};var t={},r={};e.I=(n,o)=>{o||(o=[]);var a=r[n];if(a||(a=r[n]={}),!(o.indexOf(a)>=0)){if(o.push(a),t[n])return t[n];e.o(e.S,n)||(e.S[n]={}),e.S[n];var i=[];return t[n]=i.length?Promise.all(i).then((()=>t[n]=1)):1}}})(),e(1417)})();